Name:           jhdf5
Version:        3.3.2
Release:        %mkrel 5
Summary:        Java HDF5 Package
Group:          Development/Java
License:        BSD with advertising
URL:            https://support.hdfgroup.org/products/java/
Source0:        https://support.hdfgroup.org/ftp/HDF5/releases/HDF-JAVA/hdfjni-%{version}/src/HDFJava-%{version}-Source.tar.gz

Patch0:         jhdf5-jdk11.patch
Patch1:         jhdf5-0001-add-a-generic-linux-host.patch
Patch3:         jhdf5-0003-use-system-linker-for-shared-library.patch
Patch4:         libdf.diff

BuildRequires:  autoconf
BuildRequires:  sed
BuildRequires:  hdf-static
BuildRequires:  hdf5-devel
BuildRequires:  szlib-devel
BuildRequires:  java-devel
BuildRequires:  javapackages-local
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  slf4j

BuildRequires:  junit
BuildRequires:  ImageMagick
BuildRequires:  desktop-file-utils

Requires:       java-headless
Requires:       javapackages-tools
Requires:       slf4j
# hdf5 does not bump soname but check at runtime
Requires:       hdf5 = %{_hdf5_version}

%description
HDF is a versatile data model that can represent very complex data objects
and a wide variety of meta-data. It is a completely portable file format
with no limit on the number or size of data objects in the collection.

This Java package wraps the native HDF5 library.

%package        devel
Summary:        JHDF5 development files
Group:          Development/Java
Requires:       %{name} = %{version}-%{release}
Requires:       hdf5-devel

%description    devel
JHDF5 development headers and libraries.

%package -n     jhdf
Summary:        Java HDF Package
Group:          Development/Java
Requires:       java-headless
Requires:       javapackages-tools
Requires:       slf4j

%description -n jhdf
HDF is a versatile data model that can represent very complex data objects
and a wide variety of meta-data. It is a completely portable file format
with no limit on the number or size of data objects in the collection.

This Java package wraps the native HDF4 library.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%autosetup -n hdfjava-%{version} -p1

# remove useless writability check
sed -r -i '/-d "\$JH45INST"/ {N; N; N; N; N; N; d;}' configure

# remove shipped jars
find -name '*.jar' -print -delete

# build jar repo
build-jar-repository -p lib/ junit slf4j-
ln -s slf4j-api.jar lib/slf4j-api-1.7.5.jar
ln -s slf4j-nop.jar lib/slf4j-nop-1.7.5.jar

# Prevent javadoc build failure
sed -i -e 's/$(JAVADOC_FLAGS)/$(JAVADOC_FLAGS) -Xdoclint:none/' \
       -e 's,-sourcepath,-classpath $(CLASSPATH)/lib/slf4j-api-1.7.5.jar -sourcepath,' Makefile*

# Add missing H4_ prefixes, also
# neuter H5_VERS_RELEASE check (the number has gone down in recent releases!)
find . -name \*.c -type f \( \
     -exec grep -q -P '\bMAX_(NC_NAME|VAR_DIMS)\b' {} \; -print \
     -exec sed -i -r 's/\bMAX_(NC_NAME|VAR_DIMS)\b/H4_&/g' {} \; \
     -o \
     -exec grep -q -P '\bH5_VERS_RELEASE\b' {} \; -print \
     -exec sed -i -r 's/H5_VERS_RELEASE >=? [^)]*/1/' {} \; \
     \)

# artifacts location
%mvn_package org.hdfgroup:jhdf5 jhdf5
%mvn_file org.hdfgroup:jhdf5 jhdf5
%mvn_package org.hdfgroup:jhdf jhdf
%mvn_file org.hdfgroup:jhdf jhdf

%global nowarn -Wno-maybe-uninitialized -Wno-unused-but-set-variable -Wno-unused-variable -Wno-unused-function
%global compat -DH5Fget_info_vers=1 -DH5Rdereference_vers=1

%build
export CPPFLAGS='-I%{java_home}/include/linux'
%configure --with-jdk=%{java_home}/include,%{java_home}/lib \
        --with-hdf5=%{_includedir},%{_libdir} \
        --with-hdf4=%{_includedir}/hdf,%{_libdir}/hdf \
        --with-libsz=%{_includedir},%{_libdir} \
        --with-libz=%{_includedir},%{_libdir} \
        --with-libjpeg=%{_includedir},%{_libdir}

make natives JPEGLIB=-ljpeg ZLIB=-lz HDF5LIB=-lhdf5 SZLIB=-lsz \
     CC='gcc -shared %{optflags} -fPIC %nowarn %compat' \
     LDOPT='%{?__global_ldflags} -shared'
make -C hdf
make packages javadocs

%check
make tests

%install

# jars and depmap
%mvn_artifact org.hdfgroup:jhdf5:%{version} lib/jhdf5.jar
%mvn_artifact org.hdfgroup:jhdf:%{version} lib/jhdf.jar
%mvn_install -J docs/javadocs

rm -r docs/javadocs

install -Dm744 -t%{buildroot}%{_libdir}/jhdf/ lib/*/libjhdf.so
install -Dm744 -t%{buildroot}%{_libdir}/jhdf5/ lib/*/libjhdf5.so

%global _docdir_fmt %{name}

%files -f .mfiles-jhdf5
%attr(755,root,root) %{_libdir}/jhdf5/libjhdf5.so
%doc Readme.txt
%license COPYING

%files -n jhdf -f .mfiles-jhdf
%attr(755,root,root) %{_libdir}/jhdf/libjhdf.so
%license COPYING

%files javadoc -f .mfiles-javadoc
%license COPYING


%changelog
* Mon Jan 04 2021 daviddavid <daviddavid> 3.3.2-5.mga8
+ Revision: 1668820
- rebuild with fixed hdf

* Tue Oct 13 2020 daviddavid <daviddavid> 3.3.2-4.mga8
+ Revision: 1635112
- Fix build with openjdk11
- Rebuild for hdf5 1.10.6
- Add various workarounds to fix build with new HDF5

* Wed Aug 05 2020 joequant <joequant> 3.3.2-3.mga8
+ Revision: 1611198
- revert arm fix

* Fri Feb 14 2020 umeabot <umeabot> 3.3.2-2.mga8
+ Revision: 1521956
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Jan 04 2019 daviddavid <daviddavid> 3.3.2-1.mga7
+ Revision: 1349162
- new version: 3.3.2
- rebuild for new hdf5 1.10.4

* Mon Oct 22 2018 wally <wally> 3.2.1-3.mga7
+ Revision: 1323565
- fix build on aarch64

* Sun Sep 23 2018 umeabot <umeabot> 3.2.1-2.mga7
+ Revision: 1298375
- Mageia 7 Mass Rebuild

* Fri May 04 2018 daviddavid <daviddavid> 3.2.1-1.mga7
+ Revision: 1226093
- Update to latest release 3.2.1
- jdfhobj* and hdfview have been split out, so those subpackages are dropped,
  and will have to be provided by a new source package
- Rebuild for hdf5 1.8.20
- Build with libsz support

* Mon Feb 15 2016 umeabot <umeabot> 2.11.0-2.mga6
+ Revision: 960722
- Mageia 6 Mass Rebuild

* Tue Jul 21 2015 daviddavid <daviddavid> 2.11.0-1.mga6
+ Revision: 855897
- sync with fc23 (update to 2.11.0)
- rebuild for new hdf5

* Wed Oct 15 2014 umeabot <umeabot> 2.9-6.mga5
+ Revision: 750955
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.9-5.mga5
+ Revision: 680808
- Mageia 5 Mass Rebuild

* Fri Jan 03 2014 dmorgan <dmorgan> 2.9-4.mga4
+ Revision: 564048
- Rebuild against current hdf5
- Upgrade to the Java packaging draft (JNI jar/so location)
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
+ fwang <fwang>
- use configure2_5x
- update patches
- new version 2.9

* Sat Jan 12 2013 umeabot <umeabot> 2.8-11.mga3
+ Revision: 355443
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 dmorgan <dmorgan> 2.8-10.mga3
+ Revision: 343443
- Install lib in libdir

* Wed Jan 09 2013 dmorgan <dmorgan> 2.8-9.mga3
+ Revision: 343397
- imported package jhdf5


* Wed Dec 19 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 2.8-9
- revbump after jnidir change

* Mon Dec 03 2012 Orion Poplawski <orion@cora.nwra.com> - 2.8-8
- Rebuild for hdf5 1.8.10
- Add BR libjpeg-devel

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.8-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue May 15 2012 Orion Poplawski <orion@cora.nwra.com> - 2.8-6
- Rebuild with hdf5 1.8.9

* Mon Feb 13 2012 Clément David <davidcl@fedoraproject.org> - 2.8-5
- bump version to depends on latest hdf5

* Tue Jan 31 2012 Clément David <davidcl@fedoraproject.org> - 2.8-4
- fix hdfview CLASSPATH

* Mon Jan 30 2012 Clément David <davidcl@fedoraproject.org> - 2.8-3
- split jhdfobj as an object oriented API of jhdf and jhdf5.

* Fri Jan 27 2012 Clément David <davidcl@fedoraproject.org> - 2.8-2
- use %%{_hdf5_version} for hdfview
- use same jhdf and jhdf5 versions for hdfview

* Wed Jan 25 2012 Clément David <davidcl@fedoraproject.org> - 2.8-1
- update to version 2.8

* Wed Jan 25 2012 Clément David <davidcl@fedoraproject.org> - 2.7-9
- move jars to more standard locations

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.7-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Nov 22 2011 Orion Poplawski <orion@cora.nwra.com> - 2.7-7
- use %%{_hdf5_version}

* Thu Nov 17 2011 Clément David <c.david86@gmail.com> - 2.7-6
- use %%{hdf5ver} to avoid runtime crash

* Thu Nov 03 2011 Clément David <c.david86@gmail.com> - 2.7-5
- rebuilt

* Thu Nov  3 2011 Clément David <c.david86@gmail.com> - 2.7-4
- remove rpm-build BuildRequire

* Tue Oct 25 2011 Clément David <c.david86@gmail.com> - 2.7-3
- Fix executable permissions
- pass rpmlint

* Tue Aug 16 2011 Clément David <c.david86@gmail.com> - 2.7-2
- Update mime types to x-hdf and x-hdf5

* Tue Aug 16 2011 Clément David <c.david86@gmail.com> - 2.7-1
- Initial packaging

